Welcome to Cookiecutter Python Package documentation!
=====================================================

.. include:: ../README.rst


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   introduction
   why_this_library
   usage/generate_project
   usage/use_cases
   modules


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
